package com.huguesjohnson;

/*
FortuneCookie.java
Copyright  (C) 2000-2003 Hugues Johnson

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See
the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

import java.lang.Math;
import java.lang.String;

/** class FortuneCookie retrieves a random fortune from a list.
* All fortunes are from actual fortune cookies, spelling and grammatical errors were left intact.
* The array is stored in alphabetical order to help avoid duplicates.
*/
public abstract class FortuneCookie{
     final private static String[] fortunes={
          "A sudden change in plans will lead to good fortune.",
          "A thrilling time is in your immediate future.",
          "A well-directed imagination is the source of great deeds.",
          "An old friend will try to contact you.",  		
          "Back away from individuals who are impulsive.",
          "Be careful in whom you share your confidence",
          "Change your routine.",
          "Concentration leads to success.",
          "Depart from the path which fate has you assigned.",
          "Do not do to others what you do not want done to yourself",
          "Don't be hasty, prosperity will knock on your door soon.",
          "Fame & fortune are in your stars.",
          "Find release from your cares, have a good time.",
          "From now on your kindness will lead you to success.",
          "Good fortune will soon find you.",
          "Good news will come to you by mail.",
          "Good news will come to you from far away.",
          "Good things are said about you.",
          "Grand adventures await those who are willing to turn the corner.",
          "Hang in there, within sight is the rainbow",
          "He who hurries cannot walk with dignity.",
          "It is better to be envied than to be pitied.",
          "It is better to try to idealize the real than to realize the ideal.",
          "Keep expectations reasonable.",
          "Keep your feet on the ground even though friends flatter you.",
          "Learn a new language.",
          "Life to you is a dashing and bold adventure.",
          "Luck is on your side this month.",
          "Many ideals are becoming real.",
          "Mentor someone.",
          "More money and travel is in your future.",
          "No one conquers who doesn't fight.",
          "Nothing is certain but the unforeseen.",
          "Now is a good time to finish up old tasks.",
          "Now is the time to try something new.",
          "Old acquaintances are important this week.",
          "On the first week of the next month, do something just for you.",
          "Pennies from heaven find their way to your doorstep this year!",
          "Shopping expeditions should prove all you'd hoped for.",
          "Simplicity and clarity should be your theme in dress.",
          "Solutions will come to you while you are walking.",
          "Soon you will encounter a whole new world of opportunity.",
          "Strike iron while it is hot.",
          "Take charge of your life and decisions.",
          "That long-sought opportunity will soon arise.",
          "The heart is wiser than the intellect.",
          "The only good is knowledge and the only evil ignorance.",
          "The philosophy of one century is the common sense of the next.",
          "The project that you have in mind now gains momentum.",
          "The tide of change approaches.",
          "The time is right to make new friends.",
          "The will of the people is the best law.",
          "Traveling with your family can be an enjoyment.",
          "Tuesday & Thursday stack odds in your favor.",
          "Tuesday is an especially important day for you.",
          "Two things to aim for in life - to get what you want and to enjoy it.",
          "Versatility is one of your outstanding traits.",
          "Wise men learn more from fools, than fools from the wise.",
          "With renewed energy, accomplish what you can.",
          "You and your partner will be happy in your life together.",
          "You are contemplative and analytical by nature.",
          "You are never bitter, deceptive, or petty.",
          "You are not one to make quick, rash decisions.",
          "You are the center of every group's attention.",
          "You believe in the goodness of mankind.",
          "You display the wonderful traits of charm and courtesy.",
          "You emerge victorious from the maze you've been traveling in.",
          "You have an active mind and a keen imagination.",
          "You have an important new business development shaping up.",
          "You love peace.",
          "You love sports, horses, and gambling but not to excess.",
          "You may attend a party where strange customs prevail.",
          "You will be fortunate in everything you put your hands to.",
          "You will be singled out for promotion.",
          "You will be unusually successful in business",
          "You will conquer obstacles to achieve success.",
          "You will do well to expand your business.",
          "You will have an enjoyable experience in the future.",
          "You will inherit a large sum of money.",
          "You will inherit some money or a small piece of land.",
          "You will never need to worry about a steady income.",
          "You will never regret the present, you live life to its fulliest!",
          "You will soon be crossing the great waters.",
          "You will travel far and wide, both pleasure and business.",
          "You will witness a special ceremony.",
          "Your charm and courtesy will be advantageous in goal.",
          "Your emotional nature is strong and sensitive.",
          "Your happiness is intertwined with your outlook on life.",
          "Your life will be filled with sunshine.",
          "Your life will be happy and peaceful.",
          "Your long forgotten kindness to someone will bring a substantial sum of money.",
          "Your luck has been completely changed today.",
          "Your mind being creative and original, will make you famous",
          "Your past success will be overshadowed by your future successes.",
          "Your present plans are going to succeed.",
          "Your principles mean more to you than money or success.",
          "Your social life could be glamourous and rewarding now.",
          "Your talents are in fine shape, utilize them to their fulliest."
     };

     /** getFortune retrieves a random fortune from a static array of fortunes.
     * @return fortune
     */      
     public final static String getFortune(){
          int max=fortunes.length-1; 
          int min=0; 
          int randomIndex=(int) Math.round(Math.random()*(max-min)+min);
          return(fortunes[randomIndex]);
     }
}